==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence.md <==
# AmazonLocationServiceGeofence


```text
aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence
```

```text
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')
```



| Illustration | AmazonLocationServiceGeofence | AmazonLocationServiceGeofenceCard | AmazonLocationServiceGeofenceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence.png) | ![illustration for AmazonLocationServiceGeofence](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence.Local.png) | ![illustration for AmazonLocationServiceGeofenceCard](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofenceCard.Local.png) | ![illustration for AmazonLocationServiceGeofenceGroup](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofenceGroup.Local.png) |




## AmazonLocationServiceGeofence

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofence
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofence('AmazonLocationServiceGeofence', 'Amazon Location Service Geofence', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofence
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofence('AmazonLocationServiceGeofence', 'Amazon Location Service Geofence', 'an optional tech label')
@enduml
```

## AmazonLocationServiceGeofenceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceCard('AmazonLocationServiceGeofenceCard', 'Amazon Location Service Geofence Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceCard('AmazonLocationServiceGeofenceCard', 'Amazon Location Service Geofence Card', 'an optional description')
@enduml
```

## AmazonLocationServiceGeofenceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceGroup('AmazonLocationServiceGeofenceGroup', 'Amazon Location Service Geofence Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceGroup('AmazonLocationServiceGeofenceGroup', 'Amazon Location Service Geofence Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence.md <==
# AmazonLocationServiceGeofence


```text
aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence
```

```text
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')
```



| Illustration | AmazonLocationServiceGeofence | AmazonLocationServiceGeofenceCard | AmazonLocationServiceGeofenceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence.png) | ![illustration for AmazonLocationServiceGeofence](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence.Local.png) | ![illustration for AmazonLocationServiceGeofenceCard](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofenceCard.Local.png) | ![illustration for AmazonLocationServiceGeofenceGroup](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofenceGroup.Local.png) |




## AmazonLocationServiceGeofence

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofence
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofence('AmazonLocationServiceGeofence', 'Amazon Location Service Geofence', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofence
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofence('AmazonLocationServiceGeofence', 'Amazon Location Service Geofence', 'an optional tech label')
@enduml
```

## AmazonLocationServiceGeofenceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceCard('AmazonLocationServiceGeofenceCard', 'Amazon Location Service Geofence Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceCard('AmazonLocationServiceGeofenceCard', 'Amazon Location Service Geofence Card', 'an optional description')
@enduml
```

## AmazonLocationServiceGeofenceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceGroup('AmazonLocationServiceGeofenceGroup', 'Amazon Location Service Geofence Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServiceGeofenceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServiceGeofence')

' renders the element
AmazonLocationServiceGeofenceGroup('AmazonLocationServiceGeofenceGroup', 'Amazon Location Service Geofence Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
